@@ -12,7 +12,12 @@ import woodwork as ww
 from evalml.automl.utils import tune_binary_threshold
 from evalml.exceptions import PipelineScoreError
 from evalml.preprocessing import split_data
-from evalml.problem_types import is_binary, is_classification, is_multiclass
+from evalml.problem_types import (
+    is_binary,
+    is_classification,
+    is_multiclass,
+    is_time_series,
+)
 
 
 class EngineComputation(ABC):
@@ -129,8 +134,17 @@ def train_pipeline(pipeline, X, y, automl_config, schema=True):
         automl_config.optimize_thresholds
         and pipeline.can_tune_threshold_with_objective(threshold_tuning_objective)
     ):
+        test_size_ = (
+            pipeline.forecast_horizon / len(X)
+            if is_time_series(automl_config.problem_type)
+            else 0.2
+        )
         X, X_threshold_tuning, y, y_threshold_tuning = split_data(
-            X, y, pipeline.problem_type, test_size=0.2, random_seed=pipeline.random_seed
+            X,
+            y,
+            pipeline.problem_type,
+            test_size=test_size_,
+            random_seed=pipeline.random_seed,
         )
     cv_pipeline = pipeline.clone()
     cv_pipeline.fit(X, y)
@@ -140,6 +154,8 @@ def train_pipeline(pipeline, X, y, automl_config, schema=True):
         cv_pipeline.problem_type,
         X_threshold_tuning,
         y_threshold_tuning,
+        X,
+        y,
     )
     return cv_pipeline
 
