@@ -113,3 +113,8 @@ class DataCheckMessageCode(Enum):
         "timeseries_parameters_not_compatible_with_split"
     )
     """Message code when the time series parameters are too large for the smallest data split."""
+
+    TIMESERIES_TARGET_NOT_COMPATIBLE_WITH_SPLIT = (
+        "timeseries_target_not_compatible_with_split"
+    )
+    """Message code when any training and validation split of the time series target doesn't contain all classes."""
