@@ -40,7 +40,9 @@ from evalml.problem_types import (
     ProblemTypes,
     handle_problem_types,
     is_regression,
+    is_time_series,
 )
+from evalml.utils import infer_feature_types
 
 
 def pytest_configure(config):
@@ -202,12 +204,14 @@ def get_ts_X_y():
     ):
         X = pd.DataFrame(index=[i + 1 for i in range(50)])
         dates = pd.date_range("1/1/21", periods=50)
-        feature = [1, 5, 2] * 10 + [3, 1] * 10
+        feature = pd.Series([1, 5, 2] * 10 + [3, 1] * 10, index=X.index)
         y = pd.Series([1, 2, 3, 4, 5, 6, 5, 4, 3, 2] * 5)
+        X.ww.init()
+        y = ww.init_series(y)
 
-        X_train = X[:40]
-        X_test = X[40:]
-        y_train = y[:40]
+        X_train = X.ww.iloc[:40]
+        X_test = X.ww.iloc[40:]
+        y_train = y.ww.iloc[:40]
 
         if train_features_index_dt:
             X_train.index = dates[:40]
@@ -216,11 +220,11 @@ def get_ts_X_y():
         if test_features_index_dt:
             X_test.index = dates[40:]
         if not no_features:
-            X_train["Feature"] = feature[:40]
-            X_test["Feature"] = feature[40:]
+            X_train.ww["Feature"] = pd.Series(feature[:40].values, index=X_train.index)
+            X_test.ww["Feature"] = pd.Series(feature[40:].values, index=X_test.index)
             if datetime_feature:
-                X_train["Dates"] = dates[:40]
-                X_test["Dates"] = dates[40:]
+                X_train.ww["Dates"] = pd.Series(dates[:40].values, index=X_train.index)
+                X_test.ww["Dates"] = pd.Series(dates[40:].values, index=X_test.index)
         if train_none:
             X_train = None
 
@@ -229,154 +233,101 @@ def get_ts_X_y():
     return _get_X_y
 
 
-def create_mock_pipeline(estimator, problem_type, add_label_encoder=False):
-    est_parameters = (
+def create_mock_pipeline(
+    estimator, problem_type, parameters=None, add_label_encoder=False
+):
+    pipeline_parameters = (
         {estimator.name: {"n_jobs": 1}}
-        if estimator.model_family
-        not in [ModelFamily.SVM, ModelFamily.DECISION_TREE, ModelFamily.VOWPAL_WABBIT]
+        if (
+            estimator.model_family
+            not in [
+                ModelFamily.SVM,
+                ModelFamily.DECISION_TREE,
+                ModelFamily.VOWPAL_WABBIT,
+                ModelFamily.PROPHET,
+            ]
+            and "Elastic Net" not in estimator.name
+        )
         else {}
     )
 
+    if parameters is not None:
+        pipeline_parameters.update(parameters)
+
+    custom_name = (
+        f"Pipeline with {estimator.name}"
+        if add_label_encoder is False
+        else f"Pipeline with {estimator.name} w/ Label Encoder"
+    )
+    component_graph = (
+        [estimator]
+        if add_label_encoder is False
+        else {
+            "Label Encoder": ["Label Encoder", "X", "y"],
+            estimator.name: [
+                estimator,
+                "Label Encoder.x",
+                "Label Encoder.y",
+            ],
+        }
+    )
+
     if problem_type == ProblemTypes.BINARY:
-
-        class MockBinaryPipelineWithOnlyEstimator(BinaryClassificationPipeline):
-            custom_name = (
-                f"Pipeline with {estimator.name}"
-                if add_label_encoder is False
-                else f"Pipeline with {estimator.name} w/ Label Encoder"
-            )
-            component_graph = (
-                [estimator]
-                if add_label_encoder is False
-                else {
-                    "Label Encoder": ["Label Encoder", "X", "y"],
-                    estimator.name: [
-                        estimator,
-                        "Label Encoder.x",
-                        "Label Encoder.y",
-                    ],
-                }
-            )
-            parameters = est_parameters
-
-            def __init__(self, parameters, random_seed=0):
-                super().__init__(
-                    self.component_graph,
-                    parameters=parameters,
-                    custom_name=self.custom_name,
-                    random_seed=random_seed,
-                )
-
-        return MockBinaryPipelineWithOnlyEstimator
+        return BinaryClassificationPipeline(
+            component_graph, parameters=pipeline_parameters, custom_name=custom_name
+        )
     elif problem_type == ProblemTypes.MULTICLASS:
-
-        class MockMulticlassPipelineWithOnlyEstimator(MulticlassClassificationPipeline):
-            custom_name = (
-                f"Pipeline with {estimator.name}"
-                if add_label_encoder is False
-                else f"Pipeline with {estimator.name} w/ Label Encoder"
-            )
-            component_graph = (
-                [estimator]
-                if add_label_encoder is False
-                else {
-                    "Label Encoder": ["Label Encoder", "X", "y"],
-                    estimator.name: [
-                        estimator,
-                        "Label Encoder.x",
-                        "Label Encoder.y",
-                    ],
-                }
-            )
-            parameters = est_parameters
-
-            def __init__(self, parameters, random_seed=0):
-                super().__init__(
-                    self.component_graph,
-                    parameters=parameters,
-                    custom_name=self.custom_name,
-                    random_seed=random_seed,
-                )
-
-        return MockMulticlassPipelineWithOnlyEstimator
+        return MulticlassClassificationPipeline(
+            component_graph, parameters=pipeline_parameters, custom_name=custom_name
+        )
     elif problem_type == ProblemTypes.REGRESSION:
-
-        class MockRegressionPipelineWithOnlyEstimator(RegressionPipeline):
-            custom_name = f"Pipeline with {estimator.name}"
-            component_graph = [estimator]
-            parameters = est_parameters
-
-        return MockRegressionPipelineWithOnlyEstimator
+        return RegressionPipeline(
+            component_graph, parameters=pipeline_parameters, custom_name=custom_name
+        )
     elif problem_type == ProblemTypes.TIME_SERIES_REGRESSION:
-
-        class MockTSRegressionPipelineWithOnlyEstimator(TimeSeriesRegressionPipeline):
-            custom_name = f"Pipeline with {estimator.name}"
-            component_graph = [estimator]
-            parameters = est_parameters
-
-        return MockTSRegressionPipelineWithOnlyEstimator
+        return TimeSeriesRegressionPipeline(
+            component_graph, parameters=pipeline_parameters, custom_name=custom_name
+        )
     elif problem_type == ProblemTypes.TIME_SERIES_BINARY:
-
-        class MockTSRegressionPipelineWithOnlyEstimator(
-            TimeSeriesBinaryClassificationPipeline
-        ):
-            custom_name = (
-                f"Pipeline with {estimator.name}"
-                if add_label_encoder is False
-                else f"Pipeline with {estimator.name} w/ Label Encoder"
-            )
-            component_graph = (
-                [estimator]
-                if add_label_encoder is False
-                else {
-                    "Label Encoder": ["Label Encoder", "X", "y"],
-                    estimator.name: [
-                        estimator,
-                        "Label Encoder.x",
-                        "Label Encoder.y",
-                    ],
-                }
-            )
-            parameters = est_parameters
-
-        return MockTSRegressionPipelineWithOnlyEstimator
+        return TimeSeriesBinaryClassificationPipeline(
+            component_graph, parameters=pipeline_parameters, custom_name=custom_name
+        )
     elif problem_type == ProblemTypes.TIME_SERIES_MULTICLASS:
-
-        class MockTSRegressionPipelineWithOnlyEstimator(
-            TimeSeriesMulticlassClassificationPipeline
-        ):
-            custom_name = (
-                f"Pipeline with {estimator.name}"
-                if add_label_encoder is False
-                else f"Pipeline with {estimator.name} and label encoder"
-            )
-            component_graph = (
-                [estimator]
-                if add_label_encoder is False
-                else {
-                    "Label Encoder": ["Label Encoder", "X", "y"],
-                    estimator.name: [
-                        estimator,
-                        "Label Encoder.x",
-                        "Label Encoder.y",
-                    ],
-                }
-            )
-            parameters = est_parameters
-
-        return MockTSRegressionPipelineWithOnlyEstimator
+        return TimeSeriesMulticlassClassificationPipeline(
+            component_graph, parameters=pipeline_parameters, custom_name=custom_name
+        )
 
 
 @pytest.fixture
 def all_pipeline_classes():
+    ts_parameters = {
+        "pipeline": {
+            "time_index": "date",
+            "gap": 1,
+            "max_delay": 1,
+            "forecast_horizon": 3,
+        },
+    }
+
     all_possible_pipeline_classes = []
     for estimator in _all_estimators():
         for problem_type in estimator.supported_problem_types:
+
             all_possible_pipeline_classes.append(
-                create_mock_pipeline(estimator, problem_type, add_label_encoder=False)
+                create_mock_pipeline(
+                    estimator,
+                    problem_type,
+                    parameters=ts_parameters if is_time_series(problem_type) else None,
+                    add_label_encoder=False,
+                )
             )
             all_possible_pipeline_classes.append(
-                create_mock_pipeline(estimator, problem_type, add_label_encoder=True)
+                create_mock_pipeline(
+                    estimator,
+                    problem_type,
+                    parameters=ts_parameters if is_time_series(problem_type) else None,
+                    add_label_encoder=True,
+                )
             )
     return all_possible_pipeline_classes
 
@@ -384,40 +335,40 @@ def all_pipeline_classes():
 @pytest.fixture
 def all_binary_pipeline_classes(all_pipeline_classes):
     return [
-        pipeline_class
-        for pipeline_class in all_pipeline_classes
-        if issubclass(pipeline_class, BinaryClassificationPipeline)
-        and "label encoder" not in pipeline_class.custom_name
+        pipeline
+        for pipeline in all_pipeline_classes
+        if isinstance(pipeline, BinaryClassificationPipeline)
+        and "label encoder" not in pipeline.custom_name
     ]
 
 
 @pytest.fixture
 def all_binary_pipeline_classes_with_encoder(all_pipeline_classes):
     return [
-        pipeline_class
-        for pipeline_class in all_pipeline_classes
-        if issubclass(pipeline_class, BinaryClassificationPipeline)
-        and "label encoder" in pipeline_class.custom_name
+        pipeline
+        for pipeline in all_pipeline_classes
+        if isinstance(pipeline, BinaryClassificationPipeline)
+        and "label encoder" in pipeline.custom_name
     ]
 
 
 @pytest.fixture
 def all_multiclass_pipeline_classes(all_pipeline_classes):
     return [
-        pipeline_class
-        for pipeline_class in all_pipeline_classes
-        if issubclass(pipeline_class, MulticlassClassificationPipeline)
-        and "label encoder" not in pipeline_class.custom_name
+        pipeline
+        for pipeline in all_pipeline_classes
+        if isinstance(pipeline, MulticlassClassificationPipeline)
+        and "label encoder" not in pipeline.custom_name
     ]
 
 
 @pytest.fixture
 def all_multiclass_pipeline_classes_with_encoder(all_pipeline_classes):
     return [
-        pipeline_class
-        for pipeline_class in all_pipeline_classes
-        if issubclass(pipeline_class, MulticlassClassificationPipeline)
-        and "label encoder" in pipeline_class.custom_name
+        pipeline
+        for pipeline in all_pipeline_classes
+        if isinstance(pipeline, MulticlassClassificationPipeline)
+        and "label encoder" in pipeline.custom_name
     ]
 
 
@@ -563,6 +514,36 @@ def X_y_categorical_classification():
     return X, y
 
 
+@pytest.fixture
+def X_y_based_on_pipeline_or_problem_type(X_y_binary, X_y_multi, X_y_regression):
+    def _X_y_based_on_pipeline_or_problem_type(pipeline_or_type):
+        problem_types = {
+            ProblemTypes.BINARY: "binary",
+            ProblemTypes.MULTICLASS: "multiclass",
+            ProblemTypes.REGRESSION: "regression",
+        }
+        pipeline_classes = {
+            BinaryClassificationPipeline: "binary",
+            MulticlassClassificationPipeline: "multiclass",
+            RegressionPipeline: "regression",
+        }
+
+        if pipeline_or_type in problem_types:
+            problem_type = problem_types[pipeline_or_type]
+        elif pipeline_or_type in pipeline_classes:
+            problem_type = pipeline_classes[pipeline_or_type]
+
+        if problem_type == "binary":
+            X, y = X_y_binary
+        elif problem_type == "multiclass":
+            X, y = X_y_multi
+        else:
+            X, y = X_y_regression
+        return X, y
+
+    return _X_y_based_on_pipeline_or_problem_type
+
+
 @pytest.fixture()
 def text_df():
     df = pd.DataFrame(
@@ -691,7 +672,7 @@ def example_graph():
         "OneHot_ElasticNet": ["One Hot Encoder", "Imputer.x", "y"],
         "Random Forest": ["Random Forest Classifier", "OneHot_RandomForest.x", "y"],
         "Elastic Net": ["Elastic Net Classifier", "OneHot_ElasticNet.x", "y"],
-        "Logistic Regression": [
+        "Logistic Regression Classifier": [
             "Logistic Regression Classifier",
             "Random Forest.x",
             "Elastic Net.x",
@@ -720,7 +701,7 @@ def example_pass_target_graph():
         "OneHot_ElasticNet": ["One Hot Encoder", "Imputer.x", "y"],
         "Random Forest": ["Random Forest Classifier", "OneHot_RandomForest.x", "y"],
         "Elastic Net": ["Elastic Net Classifier", "OneHot_ElasticNet.x", "y"],
-        "Logistic Regression": [
+        "Logistic Regression Classifier": [
             "Logistic Regression Classifier",
             "Random Forest.x",
             "Elastic Net.x",
@@ -748,55 +729,19 @@ def example_regression_graph():
 
 
 @pytest.fixture
-def dummy_binary_pipeline_class(dummy_classifier_estimator_class):
-    MockEstimator = dummy_classifier_estimator_class
-
-    class MockBinaryClassificationPipeline(BinaryClassificationPipeline):
-        custom_name = "Mock Binary Classification Pipeline"
-        estimator = MockEstimator
-        component_graph = [MockEstimator]
-
-        def __init__(self, parameters, random_seed=0):
-            super().__init__(
-                self.component_graph,
-                parameters=parameters,
-                custom_name=self.custom_name,
-                random_seed=random_seed,
-            )
-
-        def new(self, parameters, random_seed=0):
-            return self.__class__(parameters, random_seed=random_seed)
-
-        def clone(self):
-            return self.__class__(self.parameters, random_seed=self.random_seed)
-
-    return MockBinaryClassificationPipeline
+def dummy_binary_pipeline(dummy_classifier_estimator_class):
+    return BinaryClassificationPipeline(
+        component_graph=[dummy_classifier_estimator_class],
+        custom_name="Mock Binary Classification Pipeline",
+    )
 
 
 @pytest.fixture
-def dummy_multiclass_pipeline_class(dummy_classifier_estimator_class):
-    MockEstimator = dummy_classifier_estimator_class
-
-    class MockMulticlassClassificationPipeline(MulticlassClassificationPipeline):
-        estimator = MockEstimator
-        component_graph = [MockEstimator]
-        custom_name = "Mock Multiclass Classification Pipeline"
-
-        def __init__(self, parameters, random_seed=0):
-            super().__init__(
-                self.component_graph,
-                parameters=parameters,
-                custom_name=self.custom_name,
-                random_seed=random_seed,
-            )
-
-        def new(self, parameters, random_seed=0):
-            return self.__class__(parameters, random_seed=random_seed)
-
-        def clone(self):
-            return self.__class__(self.parameters, random_seed=self.random_seed)
-
-    return MockMulticlassClassificationPipeline
+def dummy_multiclass_pipeline(dummy_classifier_estimator_class):
+    return MulticlassClassificationPipeline(
+        component_graph=[dummy_classifier_estimator_class],
+        custom_name="Mock Multiclass Classification Pipeline",
+    )
 
 
 @pytest.fixture
@@ -819,28 +764,11 @@ def dummy_regressor_estimator_class():
 
 
 @pytest.fixture
-def dummy_regression_pipeline_class(dummy_regressor_estimator_class):
-    MockRegressor = dummy_regressor_estimator_class
-
-    class MockRegressionPipeline(RegressionPipeline):
-        component_graph = [MockRegressor]
-        custom_name = "Mock Regression Pipeline"
-
-        def __init__(self, parameters, random_seed=0):
-            super().__init__(
-                self.component_graph,
-                parameters=parameters,
-                custom_name=self.custom_name,
-                random_seed=random_seed,
-            )
-
-        def new(self, parameters, random_seed=0):
-            return self.__class__(parameters, random_seed=random_seed)
-
-        def clone(self):
-            return self.__class__(self.parameters, random_seed=self.random_seed)
-
-    return MockRegressionPipeline
+def dummy_regression_pipeline(dummy_regressor_estimator_class):
+    return RegressionPipeline(
+        component_graph=[dummy_regressor_estimator_class],
+        custom_name="Mock Regression Pipeline",
+    )
 
 
 @pytest.fixture
@@ -899,11 +827,11 @@ def dummy_ts_binary_pipeline_class(dummy_classifier_estimator_class):
 
 
 @pytest.fixture
-def dummy_ts_binary_linear_classifier_pipeline_class():
-    log_reg_classifier = LogisticRegressionClassifier
+def dummy_ts_binary_tree_classifier_pipeline_class():
+    dec_tree_classifier = DecisionTreeClassifier
 
     class MockBinaryClassificationPipeline(TimeSeriesBinaryClassificationPipeline):
-        estimator = log_reg_classifier
+        estimator = dec_tree_classifier
         component_graph = [estimator]
 
         def __init__(
@@ -916,6 +844,26 @@ def dummy_ts_binary_linear_classifier_pipeline_class():
     return MockBinaryClassificationPipeline
 
 
+@pytest.fixture
+def dummy_ts_multi_pipeline_class(dummy_classifier_estimator_class):
+    MockEstimator = dummy_classifier_estimator_class
+
+    class MockMultiClassificationClassificationPipeline(
+        TimeSeriesMulticlassClassificationPipeline
+    ):
+        estimator = MockEstimator
+        component_graph = [MockEstimator]
+
+        def __init__(
+            self, parameters, custom_name=None, component_graph=None, random_seed=0
+        ):
+            super().__init__(
+                self.component_graph, parameters=parameters, random_seed=random_seed
+            )
+
+    return MockMultiClassificationClassificationPipeline
+
+
 @pytest.fixture
 def logistic_regression_component_graph():
     component_graph = {
@@ -937,76 +885,35 @@ def logistic_regression_component_graph():
 
 
 @pytest.fixture
-def logistic_regression_multiclass_pipeline_class(logistic_regression_component_graph):
-    class LogisticRegressionMulticlassPipeline(MulticlassClassificationPipeline):
-        custom_name = "Logistic Regression Multiclass Pipeline"
-        component_graph = logistic_regression_component_graph
-
-        def __init__(self, parameters, random_seed=0):
-            super().__init__(
-                self.component_graph,
-                parameters=parameters,
-                custom_name=self.custom_name,
-                random_seed=random_seed,
-            )
-
-        def clone(self):
-            return self.__class__(self.parameters, random_seed=self.random_seed)
-
-    return LogisticRegressionMulticlassPipeline
+def logistic_regression_multiclass_pipeline(logistic_regression_component_graph):
+    return MulticlassClassificationPipeline(
+        component_graph=logistic_regression_component_graph,
+        parameters={"Logistic Regression Classifier": {"n_jobs": 1}},
+        custom_name="Logistic Regression Multiclass Pipeline",
+    )
 
 
 @pytest.fixture
-def logistic_regression_binary_pipeline_class(logistic_regression_component_graph):
-    class LogisticRegressionBinaryPipeline(BinaryClassificationPipeline):
-        component_graph = logistic_regression_component_graph
-        custom_name = "Logistic Regression Binary Pipeline"
-
-        def __init__(self, parameters, random_seed=0):
-            super().__init__(
-                self.component_graph,
-                parameters=parameters,
-                custom_name=self.custom_name,
-                random_seed=random_seed,
-            )
-
-        def new(self, parameters, random_seed=0):
-            return self.__class__(parameters, random_seed=random_seed)
-
-        def clone(self):
-            return self.__class__(self.parameters, random_seed=self.random_seed)
-
-    return LogisticRegressionBinaryPipeline
+def logistic_regression_binary_pipeline(logistic_regression_component_graph):
+    return BinaryClassificationPipeline(
+        component_graph=logistic_regression_component_graph,
+        parameters={"Logistic Regression Classifier": {"n_jobs": 1}},
+        custom_name="Logistic Regression Binary Pipeline",
+    )
 
 
 @pytest.fixture
-def linear_regression_pipeline_class():
-    class LinearRegressionPipeline(RegressionPipeline):
-        """Linear Regression Pipeline for regression problems."""
-
-        component_graph = [
+def linear_regression_pipeline():
+    return RegressionPipeline(
+        component_graph=[
             "One Hot Encoder",
             "Imputer",
             "Standard Scaler",
             "Linear Regressor",
-        ]
-        custom_name = "Linear Regression Pipeline"
-
-        def __init__(self, parameters, random_seed=0):
-            super().__init__(
-                self.component_graph,
-                parameters=parameters,
-                custom_name=self.custom_name,
-                random_seed=random_seed,
-            )
-
-        def new(self, parameters, random_seed=0):
-            return self.__class__(parameters, random_seed=random_seed)
-
-        def clone(self):
-            return self.__class__(self.parameters, random_seed=self.random_seed)
-
-    return LinearRegressionPipeline
+        ],
+        parameters={"Linear Regressor": {"n_jobs": 1}},
+        custom_name="Linear Regression Pipeline",
+    )
 
 
 @pytest.fixture
@@ -1016,7 +923,7 @@ def time_series_regression_pipeline_class():
 
         component_graph = [
             "Time Series Featurizer",
-            "DateTime Featurization Component",
+            "DateTime Featurizer",
             "Random Forest Regressor",
         ]
 
@@ -1037,14 +944,14 @@ def time_series_classification_component_graph():
             "Label Encoder.x",
             "Label Encoder.y",
         ],
-        "DateTime Featurization Component": [
-            "DateTime Featurization Component",
+        "DateTime Featurizer": [
+            "DateTime Featurizer",
             "Time Series Featurizer.x",
             "Label Encoder.y",
         ],
         "Logistic Regression Classifier": [
             "Logistic Regression Classifier",
-            "DateTime Featurization Component.x",
+            "DateTime Featurizer.x",
             "Label Encoder.y",
         ],
     }
@@ -1086,7 +993,7 @@ def time_series_multiclass_classification_pipeline_class(
 
 
 @pytest.fixture
-def decision_tree_classification_pipeline_class(X_y_categorical_classification):
+def fitted_decision_tree_classification_pipeline(X_y_categorical_classification):
     pipeline = BinaryClassificationPipeline(
         component_graph={
             "Imputer": ["Imputer", "X", "y"],
@@ -1106,75 +1013,36 @@ def decision_tree_classification_pipeline_class(X_y_categorical_classification):
 
 
 @pytest.fixture
-def nonlinear_binary_pipeline_class(example_graph):
-    class NonLinearBinaryPipeline(BinaryClassificationPipeline):
-        custom_name = "Non Linear Binary Pipeline"
-        component_graph = example_graph
-
-        def __init__(self, parameters, random_seed=0):
-            super().__init__(
-                self.component_graph,
-                parameters=parameters,
-                custom_name=self.custom_name,
-            )
-
-        def new(self, parameters, random_seed=0):
-            return self.__class__(parameters, random_seed=random_seed)
-
-        def clone(self):
-            return self.__class__(self.parameters, random_seed=self.random_seed)
-
-    return NonLinearBinaryPipeline
+def nonlinear_binary_pipeline(example_graph):
+    return BinaryClassificationPipeline(
+        component_graph=example_graph,
+        custom_name="Non Linear Binary Pipeline",
+        parameters={"Logistic Regression Classifier": {"n_jobs": 1}},
+    )
 
 
 @pytest.fixture
-def nonlinear_binary_with_target_pipeline_class(example_pass_target_graph):
-    class NonLinearBinaryWithTargetPipeline(BinaryClassificationPipeline):
-        custom_name = "Non Linear Binary With Target Pipeline"
-        component_graph = example_pass_target_graph
-
-        def __init__(self, parameters, random_seed=0):
-            super().__init__(
-                self.component_graph,
-                parameters=parameters,
-                custom_name=self.custom_name,
-            )
-
-    return NonLinearBinaryWithTargetPipeline
+def nonlinear_binary_with_target_pipeline(example_pass_target_graph):
+    return BinaryClassificationPipeline(
+        component_graph=example_pass_target_graph,
+        custom_name="Non Linear Binary With Target Pipeline",
+    )
 
 
 @pytest.fixture
-def nonlinear_multiclass_pipeline_class(example_graph):
-    class NonLinearMulticlassPipeline(MulticlassClassificationPipeline):
-        component_graph = example_graph
-
-        def __init__(self, parameters, random_seed=0):
-            super().__init__(self.component_graph, parameters=parameters)
-
-        def new(self, parameters, random_seed=0):
-            return self.__class__(parameters, random_seed=random_seed)
-
-        def clone(self):
-            return self.__class__(self.parameters, random_seed=self.random_seed)
-
-    return NonLinearMulticlassPipeline
+def nonlinear_multiclass_pipeline(example_graph):
+    return MulticlassClassificationPipeline(
+        component_graph=example_graph,
+        parameters={"Logistic Regression Classifier": {"n_jobs": 1}},
+    )
 
 
 @pytest.fixture
-def nonlinear_regression_pipeline_class(example_regression_graph):
-    class NonLinearRegressionPipeline(RegressionPipeline):
-        component_graph = example_regression_graph
-
-        def __init__(self, parameters, random_seed=0):
-            super().__init__(self.component_graph, parameters=parameters)
-
-        def new(self, parameters, random_seed=0):
-            return self.__class__(parameters, random_seed=random_seed)
-
-        def clone(self):
-            return self.__class__(self.parameters, random_seed=self.random_seed)
-
-    return NonLinearRegressionPipeline
+def nonlinear_regression_pipeline(example_regression_graph):
+    return RegressionPipeline(
+        component_graph=example_regression_graph,
+        parameters={"Linear Regressor": {"n_jobs": 1}},
+    )
 
 
 @pytest.fixture
@@ -1227,7 +1095,7 @@ def time_series_objectives(
 
 
 @pytest.fixture
-def stackable_classifiers(helper_functions):
+def stackable_classifiers():
     stackable_classifiers = []
     for estimator_class in _all_estimators():
         supported_problem_types = [
@@ -1249,7 +1117,7 @@ def stackable_classifiers(helper_functions):
 
 
 @pytest.fixture
-def stackable_regressors(helper_functions):
+def stackable_regressors():
     stackable_regressors = []
     for estimator_class in _all_estimators():
         supported_problem_types = [
@@ -1753,20 +1621,43 @@ def CustomClassificationObjectiveRanges(ranges):
 def load_daily_temp_local(n_rows=None):
     currdir_path = os.path.dirname(os.path.abspath(__file__))
     data_folder_path = os.path.join(currdir_path, "data")
-    fraud_data_path = os.path.join(data_folder_path, "daily-min-temperatures.csv")
+    temp_data_path = os.path.join(data_folder_path, "daily-min-temperatures.csv")
     X, y = load_data(
-        path=fraud_data_path,
+        path=temp_data_path,
         index=None,
         target="Temp",
         n_rows=n_rows,
     )
+    missing_date_1 = pd.DataFrame([pd.to_datetime("1984-12-31")], columns=["Date"])
+    missing_date_2 = pd.DataFrame([pd.to_datetime("1988-12-31")], columns=["Date"])
+    missing_y_1 = pd.Series([14.5], name="Temp")
+    missing_y_2 = pd.Series([14.5], name="Temp")
+
+    X = pd.concat(
+        [
+            X.iloc[:1460],
+            missing_date_1,
+            X.iloc[1460:2920],
+            missing_date_2,
+            X.iloc[2920:],
+        ]
+    ).reset_index(drop=True)
+    y = pd.concat(
+        [
+            y.iloc[:1460],
+            missing_y_1,
+            y.iloc[1460:2920],
+            missing_y_2,
+            y.iloc[2920:],
+        ]
+    ).reset_index(drop=True)
     return X, y
 
 
 @pytest.fixture
 def daily_temp_local():
     X, y = load_daily_temp_local()
-    return X, y
+    return infer_feature_types(X), infer_feature_types(y)
 
 
 @pytest.fixture
